#
# spec file for package android-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1600
%bcond_without  bundled_libfmt
%else
%bcond_with     bundled_libfmt
%endif
# currently libusb with support for SuperSpeedPlus is required,
# which is not yet released, so the one bundled is used.
%bcond_without  bundled_libusb

Name:           android-tools
Version:        35.0.2
Release:        3.5
Summary:        Android platform tools
License:        Apache-2.0 AND MIT
URL:            https://developer.android.com/studio/releases/platform-tools
Source0:        https://github.com/nmeum/android-tools/releases/download/%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE fix-install-completion.patch boo#1185883 munix9@googlemail.com -- Simplify completion
Patch0:         fix-install-completion.patch
BuildRequires:  cmake >= 3.12
BuildRequires:  go
BuildRequires:  llvm-gold
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libbrotlicommon)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libunwind-generic)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(protobuf) >= 21
BuildRequires:  pkgconfig(zlib)
Requires:       android-udev-rules
Suggests:       %{name}-mkbootimg = %{version}
Suggests:       %{name}-partition = %{version}
Provides:       %{name}-python3 = %{version}-%{release}
Obsoletes:      %{name}-python3 < %{version}-%{release}
Provides:       bundled(boringssl)
ExcludeArch:    ppc ppc64 ppc64le s390x
%if 0%{?suse_version} < 1600
BuildRequires:  clang15
BuildRequires:  gcc11-c++
BuildRequires:  python311
%else
BuildRequires:  clang
BuildRequires:  python3
%endif
%if %{with bundled_libfmt}
Provides:       bundled(fmt) = 10.2.0
%else
BuildRequires:  pkgconfig(fmt) >= 10.2.0
%endif
%if %{with bundled_libusb}
BuildRequires:  pkgconfig(libudev)
Provides:       bundled(libusb-1_0)
%else
BuildRequires:  pkgconfig(libusb-1.0)
%endif

%description
Android SDK Platform-Tools is a component for the Android SDK.
It includes tools that interface with the Android platform.

%package mkbootimg
Summary:        Android boot.img manipulation tools
Requires:       %{name} = %{version}
BuildArch:      noarch

%description mkbootimg
This package contains the Android boot.img manipulation tools.

%package partition
Summary:        Android dynamic partition tools
Requires:       %{name} = %{version}

%description partition
This package contains the Android dynamic partition tools.

%package bash-completion
Summary:        Bash completion for android-tools
BuildRequires:  bash-completion
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for android-tools.

%prep
%autosetup -p1

%build
%define __builder ninja
export GOFLAGS="-buildmode=pie -trimpath -ldflags=-buildid="

%cmake \
%if 0%{?suse_version} < 1600
	-DCMAKE_C_COMPILER=clang-15 \
	-DCMAKE_CXX_COMPILER=clang++-15 \
%else
	-DCMAKE_C_COMPILER=clang \
	-DCMAKE_CXX_COMPILER=clang++ \
%endif
%ifarch %{ix86}
	-DOPENSSL_NO_ASM=ON \
%endif
%if %{with bundled_libfmt}
	-DANDROID_TOOLS_USE_BUNDLED_FMT=ON \
%endif
%if %{with bundled_libusb}
	-DANDROID_TOOLS_USE_BUNDLED_LIBUSB=ON \
	-DANDROID_TOOLS_LIBUSB_ENABLE_UDEV=ON \
%endif
	-DBUILD_SHARED_LIBS=OFF

%cmake_build

%install
%cmake_install

# fix link
ln -sf %{_datadir}/%{name}/mkbootimg/mkbootimg.py %{buildroot}%{_bindir}/mkbootimg

# fix non-executable-script
chmod 0755 %{buildroot}%{_datadir}/%{name}/mkbootimg/gki/generate_gki_certificate.py

# fix env-script-interpreter (Leap < 16.0 requires special handling)
%if 0%{?suse_version} < 1600
%define python3_fix_shebang_path(+abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-=) \
myargs="%{**}" \
for f in ${myargs}; do \
  [ -f $f ] && sed -i "1s@#\\!.*python.*@#\\!$(realpath %{__python311})@" $f \
done
%endif
%python3_fix_shebang_path %{buildroot}%{_bindir}/*
%python3_fix_shebang_path %{buildroot}%{_datadir}/%{name}/mkbootimg/*
%python3_fix_shebang_path %{buildroot}%{_datadir}/%{name}/mkbootimg/gki/*

%check
# call some tools, e.g. to test python3 compatibility
export PATH=%{buildroot}%{_bindir}:$PATH
export PYTHONDONTWRITEBYTECODE=1
adb --version
fastboot --version
avbtool version
mkbootimg --help

%files
%license LICENSE
%doc README.md
%{_bindir}/adb
%{_bindir}/append2simg
%{_bindir}/avbtool
%{_bindir}/e2fsdroid
%{_bindir}/ext2simg
%{_bindir}/fastboot
%{_bindir}/img2simg
%{_bindir}/make_f2fs
%{_bindir}/mke2fs.android
%{_bindir}/simg2img
%{_bindir}/sload_f2fs
%{_mandir}/man1/adb.1%{?ext_man}

%files mkbootimg
%license LICENSE
%{_bindir}/{mk,repack_,unpack_}bootimg
%{_bindir}/mkdtboimg
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/mkbootimg

%files partition
%license LICENSE
%doc vendor/extras/partition_tools/README.md
%{_bindir}/lp{add,dump,flash,make,unpack}

%files bash-completion
%if 0%{?suse_version} < 1600
%exclude %{_datadir}/bash-completion/completions/adb
%else
%{_datadir}/bash-completion/completions/adb
%endif
%{_datadir}/bash-completion/completions/fastboot

%changelog
* Tue Nov  5 2024 munix9@googlemail.com
- Exclude ppc ppc64 and ppc64le: Bundled boringssl doesn't support
  the big endian architectures and dropped ppc64le support
- Simplify python3 requirements
- Simplify fix-install-completion.patch
* Sun Oct 20 2024 munix9@googlemail.com
- Fix build for Leap 16.0
- Add 'Provides: bundled(...)' where appropriate
- Clean up spec file
* Sun Sep 22 2024 olaf@aepfle.de
- remove adb from bash-completion package for SLE15 because it is
  still part of bash-completion itself
- Use specific python versions for all SLE15 variants
- Require protobuf >= 21 until earlier variants are supported again
* Thu Aug 29 2024 munix9@googlemail.com
- Fix build on i586.
* Thu Aug 29 2024 munix9@googlemail.com
- Update to version 35.0.2
  * adb
  - Fix openscreen mDNS backend bug bringing down server on
    truncated query issue #294120933.
  - Make openscreen mDNS backend work on macOS.
  - Make openscreen mDNS backend default on all platforms.
  - Support to detect USB SuperSpeed+ (current and negotiated
    speeds) for diagnostic purposes.
  - Graceful shutdown: Release all USB interfaces on shutdown
    (all OSes).
  * CMake: Add option to link libusb with libudev
  * patches/adb: Combine similar patch to workaround nullability
    specifier
  * CMake: Add option to use bundled libusb library
  * CMake: Add option to use system fmt library
  * vendor: Don't use absolute dir for mkbootimg symlink
  * vendor: mkbootimg: Use builtin ${CMAKE_INSTALL_BINDIR} instead
    of relative bin
  * vendor: Remove unused native submodule
  * vendor: Remove unused incremental_delivery submodule
  * CMake: Remove leftovers after base submodule removal
  * Remove unused patch for libandroidfw
  * Remove libandroidfw: it was never used
  * CMake: Install adb man page
  * boringssl: Workaround compiler error with gcc-14 and _Generic
- Remove man-pages.tar.gz, use upstream man pages
* Sat Aug 17 2024 munix9@googlemail.com
- Fix for Factory/TW: Add 'BuildRequires: pkgconfig(zlib)'
* Sat Jun 29 2024 olaf@aepfle.de
- Use clang15 to fix build in SLE15
* Sun Apr 28 2024 munix9@googlemail.com
- Update to version 35.0.1
  * adb
  - Switch to libusb as the default on Linux issue #270205252.
  - Fix adb startup on hosts without USB.
  - Fix adb hangs caused by USB devices incorrectly reporting
    zero-length descriptors issue #302212871.
  - Fix return code of adb shell when device disconnects
    issue #321787891.
  * fastboot
  - Limit the maximum size of the incoming packet queue.
  - Remove bottlenecks that previously limited download speeds
    to around 120MB/s. Now fastboot can saturate a SuperSpeed+
    bus and achieve speeds up to 980MB/s, depending on the device.
* Fri Mar 22 2024 munix9@googlemail.com
- Update to version 34.0.5
  * adb
  - Previously, adb responded with a successful code when wireless
    pairing fails. Resolved this by returning a failure code (1) and
    user-facing error (error: protocol fault (couldn't read status
    message...)). echo $? now reports 1.
  - adb wait-for-disconnect is now operational for non-USB
    (wireless debugging).
  - Added new DbC interface for future support of ChromeOS over adb.
  * fastboot
  - Fixed flashall on Pixel 3 devices.
- Remove fix-add-make_f2fs-tool-for-fastboot.patch and
  fix-add-sload_f2fs-tool.patch (merged upstream)
* Sat Mar 16 2024 munix9@googlemail.com
- Use custom %%python3_fix_shebang_path macro for Leap
* Fri Mar 15 2024 munix9@googlemail.com
- Add upstream patch fix-add-sload_f2fs-tool.patch
  (gh#nmeum/android-tools#127) for the missing tool sload_f2fs
- Rework python3 dependencies (use %%python3_fix_shebang for
  Factory)
* Sat Sep 30 2023 munix9@googlemail.com
- Add upstream patch fix-add-make_f2fs-tool-for-fastboot.patch
  (gh#nmeum/android-tools#109)
- Remove the requirement for f2fs-tools
* Tue Sep  5 2023 munix9@googlemail.com
- Update to version 34.0.4
  * adb
  - Propagate -a (gListenAll) when adb forks an adb host server
    (previously, the flag only worked for adb -a server nodaemon)
  - Faster root and unroot
  - Reland Flag(env) guarding clear endpoint (device) feature
    for OSX usb start. (issue #270205252).
  * fastboot
  - Mac: remove retries on invalid IO iterator (flashing failure
    with LIBUSB_TRANSFER_CANCELLED)
  - Windows: fix "Sparse file is too large or invalid" when using
    "flashall"
  - All platforms: fix "ANDROID_PRODUCT_OUT not set" when using
    "update"
- Remove the files vendor.tar.gz and _service and strip
  "-mod=vendor" from GOFLAGS env var (currently superfluous)
- Remove protobuf version requirement
* Wed Jul 26 2023 olaf@aepfle.de
- Use specific python versions for 15.4 and 15.5,
  otherwise stick with plain python3
- Remove Requires for a specific python version, the interpreter
  already creates a matching Requires
* Mon Jul  3 2023 munix9@googlemail.com
- Fix for Factory/TW: Use protobuf < 22.5
- Add f2fs-tools as a requirement: Required for 'fastboot format:f2fs ...'
  (link /usr/bin/make_f2fs to /usr/sbin/mkfs.f2fs)
* Mon May 15 2023 munix9@googlemail.com
- Update to version 34.0.1
  * Upgrade to platform-tools-34.0.1 (see #111)
* Fri Mar  3 2023 munix9@googlemail.com
- Update to version 34.0.0
  * Upgrade to platform-tools-34.0.0 (see #106)
  * adb
  - Fixed zero length packet sends for macOS
    (issuetracker: 208675141).
  - Addressed unstable connectivity (MacBook high speed cable):
    frequent adb disconnects.
  - Improved error message for adb push with insufficient number
    of arguments.
  * fastboot
  - Improved flashing: flashall will now skip reboots to
    userspace if it can.
  - Fixed zero length packet sends for macOS
    (issuetracker: 208675141).
  - Fixed flashing recovery.img resulting in wrong AVB footer.
* Tue Dec 13 2022 munix9@googlemail.com
- Update to version 33.0.3p2
  * Actually update submodules to 33.0.3 (see #100)
  * Initial support for MacOS (see #95 and #97)
* Sat Nov  5 2022 munix9@googlemail.com
- Update to version 33.0.3p1
  * Fixed mkbootimg (see #78)
  * Added avbtool (see #79)
  * Fix for compatibility with Linux >= 6.0 (see #74)
  * Removal of several obsolete patches
- Remove fix-mkbootimg-gki-path.patch (fixed upstream)
- Remove fix-lpmake-help-segfault.patch (fixed upstream)
* Sun Oct 16 2022 Andreas Schwab <schwab@linux-m68k.org>
- Use python3.10 for 15.4
* Fri Oct 14 2022 munix9@googlemail.com
- Switch to clang/llvm because of build errors with gcc12 and the
  new 6.0 kernel headers (recent gcc env for Leap still required)
* Sat Sep 24 2022 munix9@googlemail.com
- Update to version 33.0.3
  * Upgrade to platform-tools-33.0.3 (see #65).
- Update to version 31.0.3p2
  * Added e2fsdroid and ext2simg (#36)
  * Fixed build with GCC 12 (#60 and #61)
  * Bumped minimum required CMake version to 3.12 (#67)
- Add man-pages.tar.gz
- Add fix-mkbootimg-gki-path.patch
- Add fix-lpmake-help-segfault.patch
- Remove fix-add-e2fsprogs-contrib.patch (added upstream)
- Remove fix-add-functional-include.patch (fixed upstream)
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- Unknown processor:s390x. Disable build for s390x.
* Fri Jun 10 2022 munix9@googlemail.com
- Add fix-add-functional-include.patch (fix gcc 12 build)
- Remove fix-pie-build.patch (obsolete)
* Wed Jan  5 2022 munix9@googlemail.com
- Update to version 31.0.3p1
  * Fixes boringssl build failure with GCC 11.2.1 (e86eabe)
  * Add boot.img manipulation tools (#52)
  * Add Dynamic Partition Tools (#51)
- Split parts of the main package into 'mkbootimg' and 'partition'
- Remove sub-package 'python3' (avbtool is now part of the main
  package, mkbootimg part of the sub-package 'mkbootimg')
- Remove fix-install-python-tools.patch
* Sun Oct 24 2021 munix9@googlemail.com
- Update to version 31.0.3
  * fastboot
  - Support flashing vbmeta_vendor.img for fastboot flashall / update.
  * aftltool removed upstream
* Wed Aug  4 2021 Petr Vorel <pvorel@suse.cz>
- Fix Supplements: supplement against bash-completion, not bash. otherwise
  bash-completion is now pulled in for everybody. Reported by dimstar.
* Tue Jul 20 2021 munix9@googlemail.com
- Update to version 31.0.2 [boo#1185883]
  * adb
  - Support forwarding to vsock on linux.
  - Fix bug in adb track-devices where devices over wireless
    debugging wouldn't immediately receive updates.
  - Implement preliminary support for mDNS device discovery
    without a separately installed mDNS service. This is
    currently disabled by default, and can be enabled by
    setting the environment variable ADB_MDNS_OPENSCREEN to 1
    when starting the adb server.
  * fastboot
  - Don't fail when unable to get boot partition size.
  - Derive device locked state from property instead of parsing
    the kernel command line.
- Switch source to https://github.com/nmeum/android-tools
- Add fix-add-e2fsprogs-contrib.patch
- Add fix-install-completion.patch
- Add fix-install-python-tools.patch
- Add fix-pie-build.patch
- Add vendor.tar.gz ("go_modules" service)
- Remove adb.bash and fastboot.bash (now included in archive)
- Remove fix_build_core.patch
- Remove fix_build_e2fsprogs.patch
- Remove fix-include-limits.patch
- Remove generate_build.rb
- Clean up/rework spec file
* Tue Jun  1 2021 munix9@googlemail.com
- Update to android-security-9.0.0_r68
- Add fix-include-limits.patch
* Mon Apr 26 2021 munix9@googlemail.com
- Fix build for Leap (use pcre2-devel instead of
  pkgconfig(libpcre))
* Thu Apr  8 2021 munix9@googlemail.com
- Update to android-security-9.0.0_r67
- Add man pages (via help2man) and bash completion for
  adb and fastboot
- Clean up spec file
* Tue Mar  2 2021 munix9@googlemail.com
- Update to android-security-9.0.0_r66
* Fri Feb  5 2021 munix9@googlemail.com
- Update to android-security-9.0.0_r65
* Tue Jan  5 2021 munix9@googlemail.com
- Update to android-security-9.0.0_r64
* Tue Dec  8 2020 munix9@googlemail.com
- Update to android-security-9.0.0_r63
* Thu Nov 26 2020 munix9@googlemail.com
- Update to android-security-9.0.0_r62
* Sat Oct 10 2020 munix9@googlemail.com
- Update to android-9.0.0_r61
* Fri Sep 18 2020 munix9@googlemail.com
- Update to android-9.0.0_r60
* Tue Jul 21 2020 munix9@googlemail.com
- Update to android-9.0.0_r58
* Sun Jan 19 2020 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r52
* Fri Nov  8 2019 munix9@googlemail.com
- moved udev-rules into new package 'android-udev-rules'
- some spec clean up
* Fri Oct 25 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r49
* Wed Oct  2 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r48
- added hack: fix for glibc >= 2.30 [by Paolo Panto (munix9)]
* Sun Aug 25 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r47
* Mon Jul 15 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r45
- Add "%%define _lto_cflags %%{nil}" line by Paolo Panto (munix9)
  to specfile.
* Thu Jun 20 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r42
- Put udev rules in _service as well
* Thu May 30 2019 Markus S <kamikazow@opensuse.org>
- Use Python3 for avbtool and mkbootimg.
* Mon May 13 2019 Markus S <kamikazow@opensuse.org>
- Update to android-9.0.0_r39
* Mon Apr 22 2019 Aleksa Sarai <asarai@suse.com>
- Update to android-9.0.0_r30
- Switch to ninja for builds with massive packaging rework.
- Update android-udev-rules.
* Thu Jan  3 2019 olaf@aepfle.de
- Detect path to g++ with C++14 support and pass it as variable
  to generated build.sh
* Mon Dec 24 2018 ecsos@opensuse.org
- Update to android-8.0.0_36
* Wed Apr 18 2018 Markus S <kamikazow@opensuse.org>
- Update to android-8.0.0_17
* Mon Feb 15 2016 dmitry_r@opensuse.org
- Fix systemd-udevd warning [boo#965512]
* Mon Oct 26 2015 dmitry_r@opensuse.org
- Split udev rules to android-tools-udev package. Use rules from
  libmtp-udev by default. [boo#938659]
* Tue Jul 14 2015 dmitry_r@opensuse.org
- Update to version 5.1.1_r8
  * No changelog available
- Drop obsolete fix-overflow-in-adb_client.patch
- Drop obsolete android-tools-ppc64-types.patch
- Fix implicit definition
  * f2fs-tools-implicit-definitions.patch
* Tue Jun 23 2015 crrodriguez@opensuse.org
- 51-android.rules: Use TAG+="uaccess" instead of using
  group/mode access control.
* Fri Sep 19 2014 crrodriguez@opensuse.org
- Use udevrulesdir and call udev_rules_update when appropiate
* Fri May  2 2014 dmitry_r@opensuse.org
- Fix overflow in adb CVE-2014-1909 [bnc#863074]
  * fix-overflow-in-adb_client.patch
* Thu Feb 14 2013 dmitry_r@opensuse.org
- Update to version 4.2.2_r2
  * no changelog available
- Remove provide section from package
* Mon Jan 28 2013 dvaleev@suse.com
- fix wrong types for ppc64 (android-tools-ppc64-types.patch)
* Wed Jan 16 2013 dmitry_r@opensuse.org
- Move udev rules to correct place
* Wed Jan 16 2013 dmitry_r@opensuse.org
- Fix udev rules
* Fri Dec  7 2012 dmitry_r@opensuse.org
- Initial package
- Version 4.2.1_r1
